<p align="center">
    <a href="https://pri.meight.com"><img width=256 height=256 src="https://github.com/wearemeight/primeight/blob/master/docs_src/docs/images/logo-with-name.svg?raw=true" alt="Primeight"></a>
</p>

`primeight` is packaged with all you need to create tables, query them, and insert data into your [Cassandra](http://cassandra.apache.org/) database. 

Check the `primeight` documentation [here](https://pri.meight.com).

### Notes

If you find a bug, would like to suggest a new feature or even would like to suggest some change, please open an issue.

